//canvas.h



#ifndef __CANVAS_H
#define __CANVAS_H


//set this for anti aliased rendering
#define CANVAS_AA

class CanvasItem
{
	protected:
		GnomeCanvasItem* _item;
	public:
		CanvasItem();
		CanvasItem(GnomeCanvasItem* item);
		~CanvasItem();

		//returns
		GnomeCanvasItem* item() { return _item; }

		//sets FIXME
		void item(GnomeCanvasItem* item) { _item = item; }

		//useful
		void w2i(double* x, double* y);
		void grab(unsigned int event_mask, Cursor* cursor, guint32 etime);
		void ungrab(guint32 etime);
		void move(double x, double y);

		void signalConnect(void* func, gpointer data);

		void show();
		void hide();
		void redraw();
		//set n to 0 (or default) for direct top or bottom
		void lower(gint n = 0); //lower n times
		void raise(gint n = 0); //raise n times
};

class Canvas; //allows to use Canvas* in CanvasGroup

class CanvasGroup: public CanvasItem
{
	public:
		CanvasGroup(Canvas* canvas);
		CanvasGroup(GnomeCanvasItem* group);

		//returns
		GnomeCanvasGroup* group() { return GNOME_CANVAS_GROUP(_item); }
};


//objects
class CanvasItemLine: public CanvasItem
{
	public:
		CanvasItemLine(CanvasGroup* group, double x1, double y1, double x2, double y2, double width);

		//sets
		void setCoords(double x1, double y1, double x2, double y2);
		void setArrows(gboolean start = FALSE, gboolean end = FALSE,
				double width = 3.0, double length = 10.0, double edge = 10.0);
};

class CanvasItemRect: public CanvasItem
{
	public:
		CanvasItemRect(CanvasGroup* group, double x1, double y1, double x2, double y2, double width);

		//returns
		void get(double* x1, double* y1, double* x2, double* y2);

		//sets
		void set(double x1, double y1, double x2, double y2, double width);
};

class CanvasItemText: public CanvasItem
{
	private:
		double _x;
		double _y;
		CanvasGroup* _group;
	public:
		CanvasItemText(CanvasGroup* group, double x, double y, gchar text[]);

		//sets
		void setText(gchar text[]);
};


class Canvas: public Widget
{
	public:
		Canvas(double scroll_x, double scroll_y, gchar bg_color[]);

		//returns
		GnomeCanvasGroup* root() { return gnome_canvas_root(GNOME_CANVAS(_widget)); }

		//sets
		void setScale(double s = 1.0);

		//create a group
		CanvasGroup* newGroup();

		//coordonates
		void c2w(int cx, int cy, double* x, double* y);

		//useful
		void redraw();
		void redraw(gint x1, gint y1, gint x2, gint y2);
};

#endif //__CANVAS_H
