//widget.cpp



#include <gnome.h>
#include "theme.h"
#include "widget.h"


Widget::Widget()
{
}

Widget::Widget(GtkWidget* widget)
{
	_widget = widget;
}

Widget::~Widget()
{
	destroy();
}

//sets
void Widget::setTheme(Theme* theme)
{
	gtk_widget_modify_style(_widget, theme->style());
}

//essentials
void Widget::destroy()
{
	gtk_widget_destroy(_widget);
}

//useful
void Widget::realize()
{
	gtk_widget_realize(_widget);
}

void Widget::show()
{
	gtk_widget_show(_widget);
}

void Widget::hide()
{
	gtk_widget_hide(_widget);
}

void Widget::canDefault()
{
	GTK_WIDGET_SET_FLAGS(_widget, GTK_CAN_DEFAULT);
}

void Widget::resize(gint width, gint height)
{
	gtk_widget_set_usize(_widget, width, height);
}

void Widget::position(gint x, gint y)
{
	gtk_widget_set_uposition(_widget, x, y);
}

void Widget::sensitive(gboolean b)
{
	gtk_widget_set_sensitive(_widget, b);
}

void Widget::tooltip(char text[])
{
	gtk_tooltips_set_tip(gtk_tooltips_new(), _widget, text, NULL);
}

void Widget::alignment(gfloat xalign, gfloat yalign)
{
	gtk_misc_set_alignment(GTK_MISC(_widget), xalign, yalign);
}

void Widget::signalConnect(char event[], void* func, gpointer data)
{
	gtk_signal_connect(GTK_OBJECT(_widget), event, GtkSignalFunc(func), data);
}

//user data
void Widget::setData(gpointer data)
{
	gtk_object_set_user_data(GTK_OBJECT(_widget), data);
}

void Widget::setData(gint data)
{
	setData(GINT_TO_POINTER(data));
}

gpointer Widget::getData()
{
	return gtk_object_get_user_data(GTK_OBJECT(_widget));
}
